==> eiffelstudio-18.01.10.1424.tar: F_code/C11/js517.c <==
/*
 * Code for class JSON_ARRAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "js517.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {JSON_ARRAY}.make */
void F1177_9409 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {849,1140,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F850_6204(RTCW(tr1), arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {JSON_ARRAY}.make_empty */
void F1177_9410 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F1177_9409(Current, ((EIF_INTEGER_32) 0L));
}

/* {JSON_ARRAY}.representation */
EIF_REFERENCE F1177_9414 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	Result = RTMS_EX_H("[",1,91);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc1 = F850_6217(RTCW(tr1));
	for (;;) {
		tb1 = F682_5721(loc1);
		if (tb1) break;
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result) + O6319[Dtype(Result)-1000]);
		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R6347[Dtype(Result)-1002])(RTCW(Result), (EIF_CHARACTER_8) ',');
		}
		tr1 = F682_5712(loc1);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7115[Dtype(tr1)-1141])(RTCW(tr1));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R6343[Dtype(Result)-1002])(RTCW(Result), tr1);
		F682_5727(loc1);
	}
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R6347[Dtype(Result)-1002])(RTCW(Result), (EIF_CHARACTER_8) ']');
	RTLE;
	return Result;
}

/* {JSON_ARRAY}.add */
void F1177_9420 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3148[Dtype(tr1)-439])(RTCW(tr1), arg1);
	RTLE;
}

/* {JSON_ARRAY}.hash_code */
EIF_INTEGER_32 F1177_9424 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	loc2 = F850_6217(RTCW(tr1));
	for (;;) {
		tb1 = F682_5721(loc2);
		if (tb1) break;
		if (loc1) {
			ti4_1 = eif_bit_shift_left(((EIF_INTEGER_32) (Result % ((EIF_INTEGER_32) 8388593L))),((EIF_INTEGER_32) 8L));
			tr1 = F682_5712(loc2);
			ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5847[Dtype(tr1)-945])(RTCW(tr1));
			Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 + ti4_2);
		} else {
			tr1 = F682_5712(loc2);
			Result = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5847[Dtype(tr1)-945])(RTCW(tr1));
			loc1 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
		F682_5727(loc2);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = F850_6224(RTCW(tr1));
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result % ti4_1);
	RTLE;
	return Result;
}

/* {JSON_ARRAY}.array_representation */
EIF_REFERENCE F1177_9425 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
}

/* {JSON_ARRAY}.items */
EIF_REFERENCE F1177_9427 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit517 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C11/js517.c <==
/*
 * Code for class JSON_ARRAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "js517.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {JSON_ARRAY}.make */
void F1180_9860 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,874,0xFF01,1143,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F875_6596(RTCW(tr1), arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {JSON_ARRAY}.representation */
EIF_REFERENCE F1180_9866 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	Result = RTMS_EX_H("[",1,91);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc1 = F875_6610(RTCW(tr1));
	for (;;) {
		tb1 = F502_5626(loc1);
		if (tb1) break;
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R6654[Dtype(Result)-1006])(RTCW(Result), (EIF_CHARACTER_8) ',');
		}
		tr1 = F502_5617(loc1);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7437[Dtype(tr1)-1144])(RTCW(tr1));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R6650[Dtype(Result)-1006])(RTCW(Result), tr1);
		F502_5632(loc1);
	}
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R6654[Dtype(Result)-1006])(RTCW(Result), (EIF_CHARACTER_8) ']');
	RTLE;
	return Result;
}

/* {JSON_ARRAY}.new_cursor */
EIF_REFERENCE F1180_9868 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F875_6610(RTCW(tr1));
	RTLE;
	return Result;
}

/* {JSON_ARRAY}.add */
void F1180_9872 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5120[Dtype(tr1)-685])(RTCW(tr1), arg1);
	RTLE;
}

/* {JSON_ARRAY}.hash_code */
EIF_INTEGER_32 F1180_9876 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	loc2 = F875_6610(RTCW(tr1));
	for (;;) {
		tb1 = F502_5626(loc2);
		if (tb1) break;
		if (loc1) {
			ti4_1 = eif_bit_shift_left(((EIF_INTEGER_32) (Result % ((EIF_INTEGER_32) 8388593L))),((EIF_INTEGER_32) 8L));
			tr1 = F502_5617(loc2);
			ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6181[Dtype(tr1)-951])(RTCW(tr1));
			Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 + ti4_2);
		} else {
			tr1 = F502_5617(loc2);
			Result = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6181[Dtype(tr1)-951])(RTCW(tr1));
			loc1 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
		F502_5632(loc2);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = F875_6617(RTCW(tr1));
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result % ti4_1);
	RTLE;
	return Result;
}

/* {JSON_ARRAY}.array_representation */
EIF_REFERENCE F1180_9877 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
}

/* {JSON_ARRAY}.items */
EIF_REFERENCE F1180_9879 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit517 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
